@@ -3,7 +3,7 @@ use strict;
 use DBI;
 
 use vars qw($VERSION);
-$VERSION = '0.14';
+$VERSION = '0.15';
 
 =head1 NAME
 
@@ -51,7 +51,7 @@ the SQL will be read from that. B<not implemented>
 If C<sql> is undefined, the C<$::DATA> or the C<0> filehandle will
 be read until exhaustion.  B<not implemented>
 
-This allows to create SQL-as-programs as follows:
+This allows one to create SQL-as-programs as follows:
 
   #!/usr/bin/perl -w -MDBIx::RunSQL -e 'create()'
   create table ...
@@ -451,13 +451,14 @@ database, this approach might not be suitable.
 
 sub split_sql {
     my( $self, $sql )= @_;
-    my @sql = split /;\r?\n/, $sql;
+    my @sql = split /;[ \t]*\r?\n/, $sql;
 
     # Because we blindly split above on /;\n/
     # we need to reconstruct multi-line CREATE TRIGGER statements here again
     my @res;
     my $trigger;
     for my $statement (@sql) {
+        next unless $statement =~ /\S/;
         if( $statement =~ /^\s*CREATE\s+TRIGGER\b/i ) {
             $trigger = $statement;
             next
